stamp

package module
v0.0.0-...-1c4c7d7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2025 License: MIT Imports: 4 Imported by: 0

README

Tests Security audit

Stamp

Stamp logo

stamp is a Go library and a command-line tool for signing local documents or blobs. It uses Notary Go packages for core functionality.

Documentation

Overview

Stamp provides functionality for digitally signing files and other artifacts.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CalculateDigest

func CalculateDigest(content []byte) (digest.Digest, error)

CalculateDigest takes a slice of bytes and returns Digest value. The content arg represents JSON doc. Digest is calculated using SHA256 algorithm.

func Main

func Main() int

Main is the entry point to the `stamp` cli.

func NewDescriptor

func NewDescriptor(content []byte) (v1.Descriptor, error)

NewDescriptor takes a slice of bytes representing JSON doc to sign and returns Descriptor value.

Types

This section is empty.

Directories

Path Synopsis
cmd
stamp command
tooling command

Jump to