Documentation
¶
Overview ¶
Stamp provides functionality for digitally signing files and other artifacts.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CalculateDigest ¶
CalculateDigest takes a slice of bytes and returns Digest value. The content arg represents JSON doc. Digest is calculated using SHA256 algorithm.
func NewDescriptor ¶
func NewDescriptor(content []byte) (v1.Descriptor, error)
NewDescriptor takes a slice of bytes representing JSON doc to sign and returns Descriptor value.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.